StaticAwsCredentialsProvider class

An AwsCredentialsProvider returning a fixed credential set.

Implemented types

Constructors

StaticAwsCredentialsProvider(AwsCredentials _credentials)
Wraps credentials.
const
StaticAwsCredentialsProvider.of({required String accessKeyId, required String secretAccessKey, String? sessionToken})
Creates a provider from raw key material.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

credentials() Future<AwsCredentials>
The credentials to sign the next request with.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited