DownloadCommand class

omnystore download — fetch an artifact, verified.

Inheritance

Constructors

DownloadCommand(Future<CliContext> context())
Creates the command.

Properties

aliases List<String>
Alternate names for this command.
no setterinherited
argParser → ArgParser
The argument parser for this command.
no setterinherited
argResults → ArgResults?
The parsed argument results for this command.
no setterinherited
category String
The command's category.
no setterinherited
context Future<CliContext>
The resolved context, memoised for the command's lifetime.
no setterinherited
contextFactory Future<CliContext> Function()
Supplies the resolved context.
finalinherited
description String
A description of this command, included in usage.
final
globalResults → ArgResults?
The parsed global argument results.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool
Whether or not this command should be hidden from help listings.
no setterinherited
invocation String
A single-line template for how to invoke this command (e.g. "pub get package").
no setteroverride
name String
The name of this command.
final
parent → Command<int>?
The command's parent command, if this is a subcommand.
no setterinherited
runner → CommandRunner<int>?
The command runner for this command.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subcommands Map<String, Command<int>>
An unmodifiable view of all sublevel commands of this command.
no setterinherited
suggestionAliases List<String>
Alternate non-functional names for this command.
no setterinherited
summary String
A short description of this command, included in parent's CommandRunner.usage.
no setterinherited
takesArguments bool
Whether or not this command takes positional arguments in addition to options.
no setterinherited
usage String
Generates a string displaying usage information for this command.
no setterinherited
usageFooter String?
An optional footer for usage.
no setterinherited

Methods

addSubcommand(Command<int> command) → void
Adds Command as a subcommand of this.
inherited
flag(String name) bool
Reads a flag.
inherited
metadata([String name = 'metadata']) Map<String, String>
Parses repeated --metadata key=value options into a map.
inherited
multi(String name) List<String>
Reads a repeatable option, with blanks dropped.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optional(String name) String?
Reads an optional option.
inherited
printUsage() → void
Prints the usage information for this command.
inherited
require(String name) String
Reads a required option, raising a usage error when absent.
inherited
run() Future<int>
Runs this command.
override
toString() String
A string representation of this object.
inherited
usageException(String message) → Never
Throws a UsageException with message.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited