StaticGlobals class

An ArgResultsSource backed by a literal map, for tests.

Implemented types

Constructors

StaticGlobals({Map<String, String> options = const {}, Map<String, bool> flags = const {}})
Creates static globals.
const

Properties

flags Map<String, bool>
Flag values.
final
hashCode int
The hash code for this object.
no setterinherited
options Map<String, String>
Option values.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

flag(String name) bool
The value of global flag name.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
option(String name) String?
The value of global option name, or null.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited