Domain class

A LetsEncrypt domain.

Constructors

Domain({required String name, required String email})
const

Properties

email String
Domain contact e-mail.
final
hashCode int
The hash code for this object.
no setterinherited
isValidName bool
no setter
name String
The domain name. Ex.: your-domain.com
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

defaultArgDelimiter RegExp
The default delimiter for fromDomainsNamesAndEmailsArgs.
getter/setter pair
regexpDomainName RegExp
final

Static Methods

asStrings(List<Domain> domains) List<String>
contains(List<Domain> domains, String name) bool
true if the list of domains contains a domain with a name of name
fromDomainsNamesAndEmails(List<String> domainNames, List<String> domainEmails) List<Domain>
Generates a list of Domain instances from pairs in the sequence of domainNames and domainEmails.
fromDomainsNamesAndEmailsArgs(String domainNamesArg, String domainEmailsArg, {RegExp? delimiter}) List<Domain>
Splits the arguments domainNamesArg and domainEmailsArg using the specified delimiter pattern and creates a list of Domains.
toNames(List<Domain> domains) String
Returns the domain names as a comma separated list