PredicateAuthorizer class

An authorizer backed by a predicate.

Implemented types

Constructors

PredicateAuthorizer(Future<bool> _predicate(Principal? principal, RouteContext context))
Creates an authorizer from predicate.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

authorize(Principal? principal, RouteContext context) Future<bool>
Whether principal (possibly null for anonymous) may proceed with the request described by context.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited