updateDescriptor method
Replaces the advertised descriptor — used to bind new organizations, mark the provider draining, or refresh reported usage.
Implementation
void updateDescriptor(ProviderDescriptor descriptor) =>
_descriptor = descriptor;
Replaces the advertised descriptor — used to bind new organizations, mark the provider draining, or refresh reported usage.
void updateDescriptor(ProviderDescriptor descriptor) =>
_descriptor = descriptor;