isReady property
bool
get
isReady
Whether the node is registered with the hub and serving.
Implementation
bool get isReady => runtime.isReady;
Whether the node is registered with the hub and serving.
bool get isReady => runtime.isReady;