publicBaseUrl property
The node's publicly reachable base URL, enabling
DataPlaneMode.direct. null means the node is not reachable and bytes
are relayed.
Implementation
final String? publicBaseUrl;
The node's publicly reachable base URL, enabling
DataPlaneMode.direct. null means the node is not reachable and bytes
are relayed.
final String? publicBaseUrl;