openReads property
int
get
openReads
The number of open download sessions, for tests and diagnostics.
Implementation
int get openReads => _reads.length;
The number of open download sessions, for tests and diagnostics.
int get openReads => _reads.length;