rpc property
The RPC server answering the hub's calls.
late because it closes over this to describe the node, which is not
available until the field initialisers have run.
Implementation
late final StoreRpcServer rpc;
The RPC server answering the hub's calls.
late because it closes over this to describe the node, which is not
available until the field initialisers have run.
late final StoreRpcServer rpc;